@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::0_90::Bulk;
-$Search::Elasticsearch::Client::0_90::Bulk::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::0_90::Bulk::VERSION = '7.301';
+package Search::Elasticsearch::Client::1_0::Bulk;
+$Search::Elasticsearch::Client::1_0::Bulk::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Client::0_90::Role::Bulk',
+with 'Search::Elasticsearch::Client::1_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Try::Tiny;
@@ -83,10 +77,12 @@ sub reindex {
     if ( ref $src eq 'HASH' ) {
         $src = {%$src};
         my $es = delete $src->{es} || $self->es;
+        my %body
+            = $es->api_version ge '1_0'
+            ? ( sort => '_doc', size => 1000 )
+            : ( search_type => 'scan', size => 500 );
         my $scroll = $es->scroll_helper(
-            search_type => 'scan',
-            size        => 500,
-            %$src
+            %body, %$src
         );
 
         $src = sub {
@@ -113,11 +109,11 @@ sub reindex {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::0_90::Bulk - A helper module for the Bulk API and for reindexing
+Search::Elasticsearch::Client::1_0::Bulk - A helper module for the Bulk API and for reindexing
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 SYNOPSIS
 
@@ -160,19 +156,19 @@ version 7.30_1
 
 =head1 DESCRIPTION
 
-This module provides a wrapper for the L<Search::Elasticsearch::Client::0_90::Direct/bulk()>
+This module provides a wrapper for the L<Search::Elasticsearch::Client::1_0::Direct/bulk()>
 method which makes it easier to run multiple create, index, update or delete
 actions in a single request. It also provides a simple interface
 for L<reindexing documents|/REINDEXING DOCUMENTS>.
 
-The L<Search::Elasticsearch::Client::0_90::Bulk> module acts as a queue, buffering up actions
+The L<Search::Elasticsearch::Client::1_0::Bulk> module acts as a queue, buffering up actions
 until it reaches a maximum count of actions, or a maximum size of JSON request
 body, at which point it issues a C<bulk()> request.
 
 Once you have finished adding actions, call L</flush()> to force the final
 C<bulk()> request on the items left in the queue.
 
-This class does L<Search::Elasticsearch::Client::0_90::Role::Bulk> and
+This class does L<Search::Elasticsearch::Client::1_0::Role::Bulk> and
 L<Search::Elasticsearch::Role::Is_Sync>.
 
 =head1 CREATING A NEW INSTANCE
@@ -204,7 +200,7 @@ Search::Elasticsearch client as the C<es> argument.
 The C<index> and C<type> parameters provide default values for
 C<index> and C<type>, which can be overridden in each action.
 You can also pass any other values which are accepted
-by the L<bulk()|Search::Elasticsearch::Client::0_90::Direct/bulk()> method.
+by the L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> method.
 
 See L</flush()> for more information about the other parameters.
 
@@ -215,7 +211,7 @@ See L</flush()> for more information about the other parameters.
     $result = $bulk->flush;
 
 The C<flush()> method sends all buffered actions to Elasticsearch using
-a L<bulk()|Search::Elasticsearch::Client::0_90::Direct/bulk()> request.
+a L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> request.
 
 =head2 Auto-flushing
 
@@ -379,7 +375,7 @@ they must be specified either in L</new()> or in every action.
     );
 
 The C<create()> helper method allows you to add multiple C<create> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::0_90::Direct/create()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/create()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -405,7 +401,7 @@ you can just pass the individual document bodies.
     );
 
 The C<index()> helper method allows you to add multiple C<index> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::0_90::Direct/index()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/index()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -418,7 +414,7 @@ parameter, instead of as C<body>.
     );
 
 The C<delete()> helper method allows you to add multiple C<delete> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::0_90::Direct/delete()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/delete()>.
 
 =head2 C<delete_ids()>
 
@@ -444,17 +440,17 @@ In this case, all you have to do is to pass in a list of IDs.
     );
 
 The C<update()> helper method allows you to add multiple C<update> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::0_90::Direct/update()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/update()>.
 An update can either use a I<partial doc> which gets merged with an existing
 doc (example 1 above), or can use a C<script> to update an existing doc
 (example 2 above). More information on C<script> can be found here:
-L<Search::Elasticsearch::Client::0_90::Direct/update()>.
+L<Search::Elasticsearch::Client::1_0::Direct/update()>.
 
 =head1 REINDEXING DOCUMENTS
 
 A common use case for bulk indexing is to reindex a whole index when
 changing the type mappings or analysis chain. This typically
-combines bulk indexing with L<scrolled searches|Search::Elasticsearch::Client::0_90::Scroll>:
+combines bulk indexing with L<scrolled searches|Search::Elasticsearch::Client::1_0::Scroll>:
 the scrolled search pulls all of the data from the source index, and
 the bulk indexer indexes the data into the new index.
 
@@ -472,7 +468,7 @@ the source for the documents which are to be reindexed.
 =head2 Reindexing from another index
 
 If the C<source> argument is a HASH ref, then the hash is passed to
-L<Search::Elasticsearch::Client::0_90::Scroll/new()> to create a new scrolled search.
+L<Search::Elasticsearch::Client::1_0::Scroll/new()> to create a new scrolled search.
 
     my $bulk = $es->bulk_helper(
         index   => 'new_index',
@@ -602,11 +598,11 @@ the C<version> numbers from the original index, then you need the following:
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
