@@ -1,13 +1,7 @@
-# Licensed to Elasticsearch B.V under one or more agreements.
-# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
-# See the LICENSE file in the project root for more information
-
-package Search::Elasticsearch::Client::0_90::Direct::Indices;
-$Search::Elasticsearch::Client::0_90::Direct::Indices::VERSION = '7.30_1'; # TRIAL
-
-$Search::Elasticsearch::Client::0_90::Direct::Indices::VERSION = '7.301';
+package Search::Elasticsearch::Client::1_0::Direct::Indices;
+$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Client::0_90::Role::API';
+with 'Search::Elasticsearch::Client::1_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
 
@@ -19,11 +13,11 @@ __PACKAGE__->_install_api('indices');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::0_90::Direct::Indices - A client for running index-level requests
+Search::Elasticsearch::Client::1_0::Direct::Indices - A client for running index-level requests
 
 =head1 VERSION
 
-version 7.30_1
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -54,9 +48,28 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<create index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-create-index.html>
+See the L<create index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-create-index.html>
 for more information.
 
+=head2 C<get()>
+
+    $response = $e->indices->get(
+        index   => 'index'   | \@indices    # optional
+        feature => 'feature' | \@features   # optional
+    );
+
+Returns the aliases, settings, mappings, and warmers for the specified indices.
+The C<feature> parameter can be set to none or more of: C<_settings>, C<_mappings>,
+C<_warmers> and C<_aliases>.
+
+See the L<get index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-index.html>.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
+    C<local>
+
 =head2 C<exists()>
 
     $bool = $e->indices->exists(
@@ -66,7 +79,13 @@ for more information.
 The C<exists()> method returns C<1> or the empty string to indicate
 whether the specified index or indices exist.
 
-See the L<index exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-indices-exists.html>
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
+    C<local>
+
+See the L<index exists docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-indices-exists.html>
 for more information.
 
 =head2 C<delete()>
@@ -78,10 +97,13 @@ for more information.
 The C<delete()> method deletes the specified indices.
 
 Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
     C<master_timeout>,
     C<timeout>
 
-See the L<delete index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-delete-index.html>
+See the L<delete index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-index.html>
 for more information.
 
 =head2 C<close()>
@@ -94,25 +116,31 @@ The C<close()> method closes the specified indices, reducing resource usage
 but allowing them to be reopened later.
 
 Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>
     C<master_timeout>,
     C<timeout>
 
-See the L<close index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-open-close.html>
+See the L<close index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html>
 for more information.
 
 =head2 C<open()>
 
     $response = $e->indices->open(
-        index => 'index' | \@indices    # optional
+        index => 'index' | \@indices    # required
     );
 
 The C<open()> method opens closed indices.
 
 Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>
     C<master_timeout>,
     C<timeout>
 
-See the L<open index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-open-close.html>
+See the L<open index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html>
 for more information.
 
 =head2 C<clear_cache()>
@@ -133,12 +161,12 @@ Query string parameters:
     C<filter_cache>,
     C<filter_keys>,
     C<id>,
-    C<ignore_indices>,
+    C<id_cache>,
     C<ignore_unavailable>,
-    C<index>,
+    C<query_cache>,
     C<recycler>
 
-See the L<clear_cache docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-clearcache.html>
+See the L<clear_cache docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-clearcache.html>
 for more information.
 
 =head2 C<refresh()>
@@ -154,10 +182,10 @@ happens automatically once every second by default.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<ignore_indices>,
+    C<force>,
     C<ignore_unavailable>
 
-See the L<refresh index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-refresh.html>
+See the L<refresh index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-refresh.html>
 for more information.
 
 =head2 C<flush()>
@@ -175,11 +203,30 @@ Query string parameters:
     C<expand_wildcards>,
     C<force>,
     C<full>,
-    C<ignore_indices>,
     C<ignore_unavailable>,
-    C<refresh>
+    C<wait_if_ongoing>
 
-See the L<flush index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-flush.html>
+See the L<flush index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-flush.html>
+for more information.
+
+=head2 C<flush_synced()>
+
+    $respnse = $e->indices->flush_synced(
+        index => 'index' | \@indices    # optional
+    );
+
+The C<flush_synced()> method does a synchronised L<flush()> on the primaries and replicas of
+all the specified indices.  In other words, after flushing it tries to write a C<sync_id>
+on the primaries and replicas to mark them as containing the same documents.  During
+recovery, if a replica has the same C<sync_id> as the primary, then it doesn't need to check
+whether the segment files on primary and replica are the same, and it can move on
+directly to just replaying the translog.  This can greatly speed up recovery.
+
+Synced flushes happens automatically in the background on indices that have not received any
+writes for a while, but the L<flush_synced()> method can be used to trigger this process
+manually, eg before shutting down.  Any new commits immediately break the sync.
+
+See the L<flush synced docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/flush.html>
 for more information.
 
 =head2 C<optimize()>
@@ -196,25 +243,48 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<flush>,
-    C<ignore_indices>,
     C<ignore_unavailable>,
     C<max_num_segments>,
     C<only_expunge_deletes>,
-    C<refresh>,
     C<wait_for_merge>
 
-See the L<optimize index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-optimize.html>
+See the L<optimize index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-optimize.html>
 for more information.
 
-=head2 C<snapshot_index()>
+=head2 C<get_upgrade()>
 
-    $response = $e->indices->snapshot_index(
+    $response = $e->indices->get_upgrade(
         index => 'index' | \@indices    # optional
     );
 
-Deprecated.
+The C<get_upgrade()> method returns information about which indices need to be
+upgraded, which can be done with the C<upgrade()> method.
 
-See the L<snapshot_index docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/>
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<human>,
+    C<ignore_unavailable>
+
+See the L<upgrade docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-upgrade.html>
+for more information.
+
+=head2 C<upgrade()>
+
+    $response = $e->indices->upgrade(
+        index => 'index' | \@indices    # optional
+    );
+
+The C<upgrade()> method upgrades all segments in the specified indices to the latest format.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
+    C<only_ancient_segments>,
+    C<wait_for_completion>
+
+See the L<upgrade docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-upgrade.html>
 for more information.
 
 =head1 MAPPING METHODS
@@ -248,11 +318,14 @@ For instance:
     );
 
 Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
     C<ignore_conflicts>,
     C<master_timeout>,
     C<timeout>
 
-See the L<put_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-put-mapping.html>
+See the L<put_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-put-mapping.html>
 for more information.
 
 =head2 C<get_mapping()>
@@ -265,7 +338,13 @@ for more information.
 The C<get_mapping()> method returns the type definitions for one, more or
 all types in one, more or all indices.
 
-See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-mapping.html>
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
+    C<local>
+
+See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-mapping.html>
 for more information.
 
 =head2 C<get_field_mapping()>
@@ -281,13 +360,20 @@ for more information.
 The C<get_field_mapping()> method returns the field definitions for one, more or
 all fields in one, more or all types and indices.
 
-See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-field-mapping.html>
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
+    C<include_defaults>,
+    C<local>
+
+See the L<get_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-field-mapping.html>
 for more information.
 
 =head2 C<exists_type()>
 
     $bool = $e->indices->exists_type(
-        index => 'index' | \@indices    # optional,
+        index => 'index' | \@indices    # required,
         type  => 'type'  | \@types      # required
     );
 
@@ -297,17 +383,17 @@ in all specified indices, and returns C<1> or the empty string.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<ignore_indices>,
-    C<ignore_unavailable>
+    C<ignore_unavailable>,
+    C<local>
 
-See the L<exists_type docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-types-exists.html>
+See the L<exists_type docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-types-exists.html>
 for more information.
 
 =head2 C<delete_mapping()>
 
     $response = $e->indices->delete_mapping(
         index => 'index' | \@indices    # required,
-        type  => 'type'                 # required
+        type  => 'type'  | \@types      # required
     );
 
 The C<delete_mapping()> method deletes the type mappings (and all documents of
@@ -316,7 +402,7 @@ that type) in all specified indices.
 Query string parameters:
     C<master_timeout>
 
-See the L<delete_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-delete-mapping.html>
+See the L<delete_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-mapping.html>
 for more information.
 
 =head1 ALIAS METHODS
@@ -343,36 +429,36 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<update_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
+See the L<update_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
 for more information.
 
 =head2 C<get_aliases()>
 
-The C<get_aliases()> method is deprecated in favour of L</get_alias()>.
-
     $result = $e->indices->get_aliases(
-        index   => 'index' | \@indices      # optional
+        index   => 'index' | \@indices,     # optional
+        alias   => 'alias' | \@aliases      # optional
     );
 
 The C<get_aliases()> method returns a list of aliases per index for all
 the specified indices.
 
 Query string parameters:
+    C<local>,
     C<timeout>
 
-See the L<get_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
+See the L<get_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
 for more information.
 
 =head2 C<put_alias()>
 
     $response = $e->indices->put_alias(
-        index => 'index',                   # required
+        index => 'index' | \@indices,       # required
         name  => 'alias',                   # required
 
         body  => { alias defn }             # optional
     );
 
-The C<put_alias()> method creates a single index alias. For instance:
+The C<put_alias()> method creates an index alias. For instance:
 
     $response = $e->indices->put_alias(
         index => 'my_index',
@@ -386,7 +472,7 @@ Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<put_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
+See the L<put_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
 for more information.
 
 =head2 C<get_alias()>
@@ -402,10 +488,10 @@ aliases in the specified indices.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<ignore_indices>,
-    C<ignore_unavailable>
+    C<ignore_unavailable>,
+    C<local>
 
-See the L<get_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
+See the L<get_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
 for more information.
 
 =head2 C<exists_alias()>
@@ -421,33 +507,34 @@ whether the specified aliases exist in the specified indices.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<ignore_indices>,
-    C<ignore_unavailable>
+    C<ignore_unavailable>,
+    C<local>
 
-See the L<exists_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
+See the L<exists_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
 for more information.
 
 =head2 C<delete_alias()>
 
     $response = $e->indices->delete_alias(
-        index   => 'index',                 # required
-        name    => 'alias'                  # required
+        index   => 'index' | \@indices        # required,
+        name    => 'alias' | \@aliases        # required
     );
 
-The C<delete_alias()> method deletes a single alias in a single index.
+The C<delete_alias()> method deletes one or more aliases from one or more
+indices.
 
 Query string parameters:
     C<master_timeout>,
     C<timeout>
 
-See the L<delete_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-aliases.html>
+See the L<delete_alias docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
 for more information.
 
 =head1 SETTINGS METHODS
 
 =head2 C<put_settings()>
 
-    $response = $e->indices->get_settings(
+    $response = $e->indices->put_settings(
         index   => 'index' | \@indices      # optional
 
         body    => { settings }
@@ -463,21 +550,33 @@ indices or all indices. For instance:
     );
 
 Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<flat_settings>,
+    C<ignore_unavailable>,
     C<master_timeout>
 
-See the L<put_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-update-settings.html>
+See the L<put_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-update-settings.html>
 for more information.
 
 =head2 C<get_settings()>
 
     $result = $e->indices->get_settings(
         index   => 'index' | \@indices      # optional
+        name    => 'name'  | \@names        # optional
     );
 
 The C<get_settings()> method retrieves the index settings for the specified
 indices or all indices.
 
-See the L<get_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-get-settings.html>
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<flat_settings>,
+    C<ignore_unavailable>,
+    C<local>
+
+See the L<get_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-settings.html>
 for more information.
 
 =head1 TEMPLATE METHODS
@@ -492,22 +591,47 @@ for more information.
 The C<put_template()> method is used to create or update index templates.
 
 Query string parameters:
+    C<create>,
+    C<flat_settings>,
     C<master_timeout>,
+    C<op_type>,
     C<order>,
-    C<timeout>
+    C<timeout>,
+    C<version>,
+    C<version_type>
 
-See the L<put_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
+See the L<put_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
 for more information.
 
 =head2 C<get_template()>
 
     $result = $e->indices->get_template(
-        name  => 'template'                 # required
+        name  => 'template'                 # optional
     );
 
 The C<get_template()> method is used to retrieve a named template.
 
-See the L<get_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
+Query string parameters:
+    C<flat_settings>,
+    C<local>,
+    C<master_timeout>
+
+See the L<get_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
+for more information.
+
+=head2 C<exists_template()>
+
+    $result = $e->indices->exists_template(
+        name  => 'template'                 # required
+    );
+
+The C<exists_template()> method is used to check whether the named template exists.
+
+Query string parameters:
+    C<local>,
+    C<master_timeout>
+
+See the L<get_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
 for more information.
 
 =head2 C<delete_template()>
@@ -520,9 +644,11 @@ The C<delete_template()> method is used to delete a named template.
 
 Query string parameters:
     C<master_timeout>,
-    C<timeout>
+    C<timeout>,
+    C<version>,
+    C<version_type>
 
-See the L<delete_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-templates.html>
+See the L<delete_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
 for more information.
 
 =head1 WARMER METHODS
@@ -531,6 +657,7 @@ for more information.
 
     $response = $e->indices->put_warmer(
         index   => 'index' | \@indices,     # optional
+        type    => 'type'  | \@types,       # optional
         name    => 'warmer',                # required
 
         body    => { warmer defn }          # required
@@ -549,28 +676,38 @@ to user searches.  For instance:
     );
 
 Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
     C<master_timeout>
 
-See the L<put_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
+See the L<put_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
 for more information.
 
 =head2 C<get_warmer()>
 
     $response = $e->indices->get_warmer(
         index   => 'index'  | \@indices,    # optional
+        type    => 'type'   | \@types,      # optional
         name    => 'warmer' | \@warmers,    # optional
     );
 
 The C<get_warmer()> method is used to retrieve warmers by name.
 
-See the L<get_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>,
+    C<local>
+
+See the L<get_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
 for more information.
 
 =head2 C<delete_warmer()>
 
     $response = $e->indices->get_warmer(
         index   => 'index'  | \@indices,    # required
-        name    => 'warmer' | \@warmers,    # optional
+        name    => 'warmer' | \@warmers,    # required
     );
 
 The C<delete_warmer()> method is used to delete warmers by name.
@@ -578,7 +715,7 @@ The C<delete_warmer()> method is used to delete warmers by name.
 Query string parameters:
     C<master_timeout>
 
-See the L<delete_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-warmers.html>
+See the L<delete_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
 for more information.
 
 =head1 STATS METHODS
@@ -586,58 +723,59 @@ for more information.
 =head2 C<stats()>
 
     $result = $e->indices->stats(
-        index   => 'index' | \@indices      # optional
+        index   => 'index'  | \@indices      # optional
+        metric  => 'metric' | \@metrics      # optional
     );
 
 The C<stats()> method returns statistical information about one, more or all
-indices.  Use the query string parameters to specify what information you
-want returned.
+indices. By default it returns all metrics, but you can limit which metrics
+are returned by specifying the C<metric>.
 
-Query string parameters:
-    C<all>,
-    C<allow_no_indices>,
-    C<clear>,
-    C<completion>,
-    C<completion_fields>,
+Allowed metrics are:
+    C<_all>,
+    C<completion>
     C<docs>,
-    C<expand_wildcards>,
     C<fielddata>,
-    C<fielddata_fields>,
-    C<fields>,
     C<filter_cache>,
     C<flush>,
     C<get>,
-    C<groups>,
     C<id_cache>,
-    C<ignore_indices>,
-    C<ignore_unavailable>,
     C<indexing>,
     C<merge>,
+    C<percolate>,
+    C<query_cache>,
     C<refresh>,
     C<search>,
+    C<segments>,
     C<store>,
     C<warmer>
 
-See the L<stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-stats.html>
+Query string parameters:
+    C<completion_fields>,
+    C<fielddata_fields>,
+    C<fields>,
+    C<groups>,
+    C<human>,
+    C<level>,
+    C<types>
+
+See the L<stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-stats.html>
 for more information.
 
-=head2 C<status()>
+=head2 C<recovery()>
 
-    $result = $e->indices->status(
+    $result = $e->indices->recovery(
         index   => 'index' | \@indices      # optional
     );
 
-Deprecated.
+Provides insight into on-going shard recoveries.
 
 Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_indices>,
-    C<ignore_unavailable>,
-    C<recovery>,
-    C<snapshot>
+    C<active_only>,
+    C<detailed>,
+    C<human>
 
-See the L<status docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-status.html>
+See the L<recovery docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-recovery.html>
 for more information.
 
 =head2 C<segments()>
@@ -652,10 +790,10 @@ that an index contains.
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
-    C<ignore_indices>,
+    C<human>,
     C<ignore_unavailable>
 
-See the L<segments docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-segments.html>
+See the L<segments docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-segments.html>
 for more information.
 
 =head1 QUERY AND ANALYSIS METHODS
@@ -674,21 +812,24 @@ for debugging analyzer configurations.
 
 Query string parameters:
     C<analyzer>,
+    C<char_filters>,
     C<field>,
     C<filters>,
     C<format>,
-    C<index>,
     C<prefer_local>,
+    C<rewrite>,
     C<text>,
     C<tokenizer>
 
-See the L<analyze docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-analyze.html>
+See the L<analyze docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-analyze.html>
 for more information.
 
 =head2 C<validate_query()>
 
     $result = $e->indices->validate_query(
         index   => 'index' | \@indices,     # optional
+        type    => 'type'  | \@types,       # optional
+
         body    => { query }
     );
 
@@ -698,23 +839,27 @@ to C<true>, in which case it includes an execution plan in the output.
 
 Query string parameters:
     C<allow_no_indices>,
+    C<analyze_wildcard>,
+    C<analyzer>,
+    C<default_operator>,
+    C<df>,
     C<expand_wildcards>,
     C<explain>,
-    C<ignore_indices>,
     C<ignore_unavailable>,
-    C<q>,
-    C<source>
+    C<lenient>,
+    C<lowercase_expanded_terms>,
+    C<q>
 
-See the L<validate_query docs|http://www.elastic.co/guide/en/elasticsearch/reference/0.90/indices-validate.html>
+See the L<validate_query docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-validate.html>
 for more information.
 
 =head1 AUTHOR
 
-Enrico Zimuel <enrico.zimuel@elastic.co>
+Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
